@@ -11,7 +11,12 @@ def drop_quilt_with(line, target):
     return dh_invoke_drop_with(line, b'quilt')
 
 
-update_rules(drop_quilt_with)
+try:
+    with open('debian/source/format', 'r') as f:
+        if f.read().strip() == '3.0 (quilt)':
+            update_rules(drop_quilt_with)
+except FileNotFoundError:
+    pass
 
 
 print("Don't specify --with=quilt, since package uses "
