@@ -17,7 +17,10 @@
 
 """Tests for lintian_brush.patches."""
 
+from io import BytesIO
+
 from breezy.tests import (
+    TestCase,
     TestCaseWithTransport,
     )
 from breezy.patches import (
@@ -27,14 +30,55 @@ from breezy.patches import (
 
 from ..patches import (
     AppliedPatches,
+    find_common_patch_suffix,
     find_patch_base,
     find_patches_branch,
     read_quilt_patches,
+    read_quilt_series,
     tree_non_patches_changes,
     upstream_with_applied_patches,
     )
 
 
+class ReadSeriesFileTests(TestCase):
+
+    def test_comment(self):
+        f = BytesIO(b"""\
+# This file intentionally left blank.
+""")
+        self.assertEqual(
+            [('This', True, ['file', 'intentionally', 'left', 'blank.'])],
+            list(read_quilt_series(f)))
+
+    def test_empty(self):
+        f = BytesIO(b"\n")
+        self.assertEqual([], list(read_quilt_series(f)))
+
+    def test_empty_line(self):
+        f = BytesIO(b"""\
+patch1
+
+patch2
+""")
+        self.assertEqual(
+            [
+                ("patch1", False, []),
+                ("patch2", False, []),
+            ], list(read_quilt_series(f)))
+
+    def test_options(self):
+        f = BytesIO(b"""\
+name -p0
+name2
+""")
+        self.assertEqual(
+            [
+                ("name", False, ["-p0"]),
+                ("name2", False, []),
+            ],
+            list(read_quilt_series(f)))
+
+
 class FindPatchBaseTests(TestCaseWithTransport):
 
     def setUp(self):
@@ -61,22 +105,6 @@ blah (0.38) unstable; urgency=medium
             self.upstream_revid, find_patch_base(self.tree))
 
 
-class ReadSeriesFileTests(TestCaseWithTransport):
-
-    def test_no_series_file(self):
-        t = self.make_branch_and_tree('.')
-        self.assertEqual([], list(read_quilt_patches(t)))
-
-    def test_comments(self):
-        t = self.make_branch_and_tree('.')
-        self.build_tree_contents([
-            ('debian/', ),
-            ('debian/patches/', ),
-            ('debian/patches/series',
-             "# This file intentionally left blank.\n")])
-        self.assertEqual([], list(read_quilt_patches(t)))
-
-
 class FindPatchBranchTests(TestCaseWithTransport):
 
     def make_named_branch_and_tree(self, path, name):
@@ -183,6 +211,19 @@ class ReadQuiltPatchesTests(TestCaseWithTransport):
         self.assertIsInstance(patches[0], Patch)
         self.assertEqual(patch.encode('utf-8'), patches[0].as_bytes())
 
+    def test_no_series_file(self):
+        t = self.make_branch_and_tree('.')
+        self.assertEqual([], list(read_quilt_patches(t)))
+
+    def test_comments(self):
+        t = self.make_branch_and_tree('.')
+        self.build_tree_contents([
+            ('debian/', ),
+            ('debian/patches/', ),
+            ('debian/patches/series',
+             "# This file intentionally left blank.\n")])
+        self.assertEqual([], list(read_quilt_patches(t)))
+
 
 class UpstreamWithAppliedPatchesTests(TestCaseWithTransport):
 
@@ -265,3 +306,22 @@ blah (0.38) unstable; urgency=medium
         self.build_tree_contents([('anotherfile', 'blah')])
         self.tree.add('anotherfile')
         self.assertEqual(1, len(list(tree_non_patches_changes(self.tree))))
+
+
+class FindCommonPatchSuffixTests(TestCase):
+
+    def test_simple(self):
+        self.assertEqual(
+            '.blah',
+            find_common_patch_suffix(['foo.blah', 'series']))
+        self.assertEqual(
+            '.patch', find_common_patch_suffix(['foo.patch', 'series']))
+        self.assertEqual(
+            '.patch', find_common_patch_suffix(['series']))
+        self.assertEqual(
+            '.blah', find_common_patch_suffix(['series'], '.blah'))
+        self.assertEqual(
+            '', find_common_patch_suffix(['series', 'foo', 'bar']))
+        self.assertEqual(
+            '.patch',
+            find_common_patch_suffix(['series', 'foo.patch', 'bar.patch']))
